@@ -1,6 +1,6 @@
 #include "config.h"
 
-int unused;
+extern int unused;
 
 #ifndef HAVE_REALLOCARRAY
 
